//+------------------------------------------------------------------+
//|                                                  Trade Assistant |
//|                                                     TA_1.12b.mq4 |
//|                                       Copyright  2008 Tom Balfe |
//|                                                                  |
//| This indicator helps you trade by giving you two signals on      |
//| multiple timeframes. It bases it's recommendations on RSI and    |
//| stochastics.                                                     |
//|                                                                  |
//| Version: 1.12b                                                   |
//|                                                                  |
//| Changelog:                                                       |
//|                                                                  |
//|    1.12b - subtracted 1 min TF and added 1 day, added overbought |
//|            and oversold handling                                 |
//|    1.12  - fixed RSI code                                        |
//|    1.11  - fixed spacing between objects                         |
//|     1.1  - added buy/sell text                                   |
//|     1.0  - first version, got arrows working                     |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Copyright  2008 Tom Balfe"
#property link      "redcarsarasota@yahoo.com"
#property indicator_separate_window

int scaleX=120,scaleY=20,offsetX=200,offsetY=4,fontSize=8;
int period[]={5,15,30,60,240,1440};
string periodStr[]={"5 MIN:","15 MIN:","30 MIN:","1 HR:","4 HR:","1 DAY:"};
string signalNameStr[]={"STOCH","RSI"};

//+------------------------------------------------------------------+
//| USER ADJUSTABLE STUFF                                            |
//+------------------------------------------------------------------+
extern  string  Stochastic_Settings   = "=== Stochastic Settings ===";
extern  int     PercentK              = 8;
extern  int     PercentD              = 3;
extern  int     Slowing               = 3;

extern  string  RSI_Settings          = "=== RSIOMA Settings ===";
extern int      RSIOMA1                = 9;
extern int      RSIOMA2                = 14;
extern int      RSIOMA_MODE           = MODE_EMA;
extern int      RSIOMA_PRICE          = PRICE_CLOSE;  

extern  string  ADX_Settings          = "=== ADX Settings ===";
extern  int     Trend                 = 20;
extern  int     ADX_Period            = 14;

extern  string  My_Symbols            = "=== Wingdings Symbols ===";
extern  int     sBuy                  = 233;
extern  int     sSell                 = 234;
extern  int     sWait                 = 54;
extern  int     sOB                   = 198; 
extern  int     sOS                   = 196;

//+------------------------------------------------------------------+
//| Initialization function                                          |
//+------------------------------------------------------------------+
int init()
  {
    //-- indicator short name
    IndicatorShortName("Trade Assistant 1.12b ");

    return(0);
  }
//+------------------------------------------------------------------+
//| Deinitialization function                                        |
//+------------------------------------------------------------------+
int deinit()
  {
   //-- need to delete objects should user remove indicator
   ObjectsDeleteAll(0,OBJ_LABEL);
    //-- delete timeframe text labels   
    for(int x=0;x<6;x++)
      for (int y=0;y<2;y++)
      { ObjectDelete("tPs"+x+y); } 
    //-- delete indicator readouts
    for (x=0;x<6;x++)
      for (y=0;y<2;y++)
      { ObjectDelete("dI"+x+y); }
    //-- delete indicator text labels
    for(y=0;y<2;y++)
      { ObjectDelete("tInd"+y); }             
    for (x=0;x<6;x++)
      for (y=0;y<2;y++)   
      { ObjectDelete("tI"+x+y); } 
   
   return(0);
  }

//+------------------------------------------------------------------+
//| MAIN LOOP                                                        |
//+------------------------------------------------------------------+

int start()
  {
    //--- create timeframe text labels 
    for (int x=0;x<6;x++)
      for (int y=0;y<2;y++)
      {
        ObjectCreate("tPs"+x+y,OBJ_LABEL,WindowFind("Trade Assistant 1.12b "),0,0);
        ObjectSetText("tPs"+x+y,periodStr[x],fontSize,"Arial Bold",LightSteelBlue);
        ObjectSet("tPs"+x+y,OBJPROP_CORNER,0);
        ObjectSet("tPs"+x+y,OBJPROP_XDISTANCE,x*scaleX+offsetX);
        ObjectSet("tPs"+x+y,OBJPROP_YDISTANCE,y*scaleY+offsetY);
      }
    
    //--- create indicator text labels
    for (y=0;y<2;y++)
      {
        ObjectCreate("tInd"+y,OBJ_LABEL,WindowFind("Trade Assistant 1.12b "),0,0);
        ObjectSetText("tInd"+y,signalNameStr[y],fontSize,"Arial Bold",PaleGoldenrod);
        ObjectSet("tInd"+y,OBJPROP_CORNER,0);
        ObjectSet("tInd"+y,OBJPROP_XDISTANCE,offsetX-55);
        ObjectSet("tInd"+y,OBJPROP_YDISTANCE,y*scaleY+offsetY);
      }
    
    //--- create blanks for arrows
    for (x=0;x<6;x++)
      for (y=0;y<2;y++)
      {
        ObjectCreate("dI"+x+y,OBJ_LABEL,WindowFind("Trade Assistant 1.12b "),0,0);
          ObjectSetText("dI"+x+y," ",10,"Wingdings",Goldenrod);
          ObjectSet("dI"+x+y,OBJPROP_CORNER,0);
          ObjectSet("dI"+x+y,OBJPROP_XDISTANCE,x*scaleX+(offsetX+80)); // scaleX == 120, offsetX == 200
          ObjectSet("dI"+x+y,OBJPROP_YDISTANCE,y*scaleY+offsetY);
      }
    
    //--- create blanks for text
    for (x=0;x<6;x++)
      for (y=0;y<2;y++)
      {
        ObjectCreate("tI"+x+y,OBJ_LABEL,WindowFind("Trade Assistant 1.12b "),0,0);
          ObjectSetText("tI"+x+y,"TEST",10,"Arial Bold",Goldenrod);
          ObjectSet("tI"+x+y,OBJPROP_CORNER,0);
          ObjectSet("tI"+x+y,OBJPROP_XDISTANCE,x*scaleX+(offsetX+45)); // scaleX == 120, offsetX == 200
          ObjectSet("tI"+x+y,OBJPROP_YDISTANCE,y*scaleY+offsetY);
      }
    
    //--- stochastics arrows
    for(x=0;x<6;x++)
    {
      if((iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_MAIN,0)) >  
        (iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_SIGNAL,0)))
        ObjectSetText("dI"+x+"0",CharToStr(sBuy),fontSize,"Wingdings",Lime);
      else if(((iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_MAIN,0)) >  
        (iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_SIGNAL,0))) &&
        ((iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_MAIN,0)>80)) &&
        (iADX(NULL,0,ADX_Period,PRICE_CLOSE,0,0) > Trend))
        ObjectSetText("dI"+x+"0",CharToStr(sOB),fontSize,"Wingdings",Lime);
      else if             
        ((iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_SIGNAL,0)) >
        (iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_MAIN,0)))
        ObjectSetText("dI"+x+"0",CharToStr(sSell),fontSize,"Wingdings",Red);         
      else if(((iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_SIGNAL,0)) >
        (iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_MAIN,0))) &&
        ((iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_MAIN,0)<20)) &&
        (iADX(NULL,0,ADX_Period,PRICE_CLOSE,0,0) > Trend))
        ObjectSetText("dI"+x+"0",CharToStr(sOS),fontSize,"Wingdings",Red);
      else
        ObjectSetText("dI"+x+"0",CharToStr(sWait),10,"Wingdings",Khaki); 
    }
    
    //--- stochastics text
    for(x=0;x<6;x++)
    {
      if((iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_MAIN,0)) >  
        (iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_SIGNAL,0)))
        ObjectSetText("tI"+x+"0"," BUY",9,"Arial Bold",Lime);
      else if(((iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_MAIN,0)) >  
        (iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_SIGNAL,0))) &&
        ((iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_MAIN,0)>80)) &&
        (iADX(NULL,0,ADX_Period,PRICE_CLOSE,0,0) > Trend))      
        ObjectSetText("tI"+x+"0"," TRND",9,"Arial Bold",Lime);
      else if             
        ((iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_SIGNAL,0)) >
        (iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_MAIN,0)))
        ObjectSetText("tI"+x+"0","SELL",9,"Arial Bold",Red);         
      else if(((iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_SIGNAL,0)) >
        (iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_MAIN,0))) &&
        ((iStochastic(NULL,period[x],PercentK,PercentD,Slowing,MODE_SMA,0,MODE_MAIN,0)<20)) &&
        (iADX(NULL,0,ADX_Period,PRICE_CLOSE,0,0) > Trend))
        ObjectSetText("tI"+x+"0","TRND",9,"Arial Bold",Red);      
      else
        ObjectSetText("tI"+x+"0","WAIT",9,"Arial Bold",Khaki); 
    }    
        
    //--- RSI arrows
    for(x=0;x<6;x++)
    {
      if ((iCustom(NULL,period[x],"RSIOMA_v2Only",RSIOMA1,RSIOMA_MODE,RSIOMA_PRICE,0,0)) > (iCustom(NULL,period[x],"RSIOMA_v2Only",RSIOMA2,RSIOMA_MODE,RSIOMA_PRICE,0,0)))
        ObjectSetText("dI"+x+"1",CharToStr(sBuy),fontSize,"Wingdings",Lime);  
      else if
         ((iCustom(NULL,period[x],"RSIOMA_v2Only",RSIOMA2,RSIOMA_MODE,RSIOMA_PRICE,0,0)) > (iCustom(NULL,period[x],"RSIOMA_v2Only",RSIOMA1,RSIOMA_MODE,RSIOMA_PRICE,0,0)))  
        ObjectSetText("dI"+x+"1",CharToStr(sSell),fontSize,"Wingdings",Red);
      else
      ObjectSetText("dI"+x+"1",CharToStr(sWait),10,"Wingdings",Khaki);
    }
    
    //--- RSI text
    for(x=0;x<6;x++)
    {
      if ((iCustom(NULL,period[x],"RSIOMA_v2Only",RSIOMA1,RSIOMA_MODE,RSIOMA_PRICE,0,0)) > (iCustom(NULL,period[x],"RSIOMA_v2Only",RSIOMA2,RSIOMA_MODE,RSIOMA_PRICE,0,0)))
        ObjectSetText("tI"+x+"1"," BUY",9,"Arial Bold",Lime);
      else if             
        ((iCustom(NULL,period[x],"RSIOMA_v2Only",RSIOMA2,RSIOMA_MODE,RSIOMA_PRICE,0,0)) > (iCustom(NULL,period[x],"RSIOMA_v2Only",RSIOMA1,RSIOMA_MODE,RSIOMA_PRICE,0,0)))
        ObjectSetText("tI"+x+"1","SELL",9,"Arial Bold",Red);         
      else
        ObjectSetText("tI"+x+"1","WAIT",9,"Arial Bold",Khaki); 
    }  
     
  return(0);
  }
  //+------------------------------------------------------------------+
  //| END MAIN LOOP                                                    |
  //+------------------------------------------------------------------+

   